@@ -43,6 +43,7 @@
 #include <kstandarddirs.h>
 #include <kcomponentdata.h>
 #include <kconfig.h>
+#include <KSharedConfig>
 
 namespace KDevelop {
 
@@ -306,10 +307,12 @@ void ClassGenerator::fetchSuperClasses(DeclarationPointer derivedClass)
     d->inheritedClasses.append(derivedClass);
 
     DUContext* context = derivedClass->internalContext();
-    foreach (const DUContext::Import& import, context->importedParentContexts())
-        if (DUContext * parentContext = import.context(context->topContext()))
-            if (parentContext->type() == DUContext::Class)
-                fetchSuperClasses( DeclarationPointer(parentContext->owner()) );
+    if (context) {
+        foreach (const DUContext::Import& import, context->importedParentContexts())
+            if (DUContext * parentContext = import.context(context->topContext()))
+                if (parentContext->type() == DUContext::Class)
+                    fetchSuperClasses( DeclarationPointer(parentContext->owner()) );
+    }
 }
 
 class ClassIdentifierPagePrivate
@@ -701,6 +704,12 @@ OutputPage::OutputPage(CreateClassWizard* parent)
 
 void OutputPage::initializePage()
 {
+     //Read the setting for lower case filenames
+    KSharedConfigPtr config = KGlobal::config();
+    KConfigGroup codegenGroup( config, "CodeGeneration" );
+    bool lower = codegenGroup.readEntry( "LowerCaseFilenames", true );
+    d->output->lowerFilenameCheckBox->setChecked(lower);
+
     updateFileNames();
     QWizardPage::initializePage();
 }
@@ -708,6 +717,11 @@ void OutputPage::initializePage()
 void OutputPage::updateFileNames() {
     d->output->headerUrl->setUrl(d->parent->generator()->headerUrlFromBase(d->parent->d->baseUrl, d->output->lowerFilenameCheckBox->isChecked()));
     d->output->implementationUrl->setUrl(d->parent->generator()->implementationUrlFromBase(d->parent->d->baseUrl, d->output->lowerFilenameCheckBox->isChecked()));
+
+    //Save the setting for next time
+    KSharedConfigPtr config = KGlobal::config();
+    KConfigGroup codegenGroup( config, "CodeGeneration" );
+    codegenGroup.writeEntry( "LowerCaseFilenames", d->output->lowerFilenameCheckBox->isChecked() );
 }
 
 void OutputPage::updateHeaderRanges(const QString & url)
