@@ -82,7 +82,7 @@ void AbstractNavigationWidget::initBrowser(int height) {
   m_browser = new KTextBrowser;
   
   // since we can embed arbitrary HTML we have to make sure it stays readable by forcing a black-white palette
-  m_browser->setPalette( QPalette( Qt::black, Qt::white ) );
+  m_browser->viewport()->setPalette( QPalette( Qt::black, Qt::white ) );
 
   m_browser->setOpenLinks(false);
   m_browser->setOpenExternalLinks(false);
@@ -115,6 +115,10 @@ void AbstractNavigationWidget::setContext(NavigationContextPointer context, int
   }
   if(context == m_context && (!context || context->alreadyComputed()))
     return;
+
+  if (!m_startContext)
+    m_startContext = m_context;
+
   m_context = context;
   update();
   
