@@ -18,6 +18,11 @@
 
 class Snippet;
 
+namespace KTextEditor
+{
+class TemplateScript;
+}
+
 /**
  * Each object of this type represents a repository of snippets. Each repository
  * has a name and will be saved to an XML file that includes all items of this repository.
@@ -84,7 +89,34 @@ public:
     /**
      * The path to this repository's file.
      */
-    const QString& getFile() const;
+    const QString& file() const;
+
+    /**
+     * The namespace associated with this repository.
+     * Used in CodeCompletion for filtering.
+     */
+    QString completionNamespace() const;
+    /**
+     * Sets the code completion namespace for this repository.
+     */
+    void setCompletionNamespace(const QString& completionNamespace);
+
+    /**
+     * The QtScript(s) associated with this repository.
+     *
+     * @since KDE 4.5
+     */
+    QString script() const;
+    /**
+     * The token identifying the script in this repository.
+     */
+    KTextEditor::TemplateScript* registeredScript() const;
+    /**
+     * Sets the QtScript(s) associated with this repository.
+     * 
+     * @since KDE 4.5
+     */
+    void setScript(const QString& script);
 
     /**
      * Remove this repository from the disk. Also deletes the item and all its children.
@@ -112,6 +144,12 @@ private:
     QString m_authors;
     /// valid filetypes for the snippets in this repo
     QStringList m_filetypes;
+    /// filtering namespace for code completion
+    QString m_namespace;
+    /// QtScript with functions to be used in the snippet
+    QString m_script;
+    /// registered script
+    KTextEditor::TemplateScript* m_registeredScript;
 };
 
 #endif
