@@ -33,8 +33,8 @@
 #include <sublime/tooldocument.h>
 
 #include <language/duchain/topducontext.h>
-#include <language/editor/editorintegrator.h>
-#include <language/backgroundparser/backgroundparser.h>
+#include <language/duchain/repositories/itemrepository.h>
+#include <language/duchain/duchain.h>
 
 #include "shellextension.h"
 
@@ -56,9 +56,9 @@
 #include "kdevplatformversion.h"
 #include "workingsetcontroller.h"
 #include <KMessageBox>
+
 #include <KTextEditor/Document>
-#include <KTextEditor/SmartInterface>
-#include <language/duchain/duchain.h>
+#include <ktexteditor/movinginterface.h>
 
 namespace KDevelop {
 
@@ -78,7 +78,7 @@ KAboutData aboutData()
     aboutData.addAuthor( ki18n("Hamish Rodda"), ki18n( "Text editor integration, definition-use chain" ), "rodda@kde.org" );
     
     aboutData.addCredit( ki18n("Matt Rogers"), KLocalizedString(), "mattr@kde.org");
-    aboutData.addCredit( ki18n("Cédric Pasteur"), ki18n("astyle and ident support"), "cedric.pasteur@free.fr" );
+    aboutData.addCredit( ki18n("Cédric Pasteur"), ki18n("astyle and indent support"), "cedric.pasteur@free.fr" );
     aboutData.addCredit( ki18n("Evgeniy Ivanov"), ki18n("Distributed VCS, Git, Mercurial"), "powerfox@kde.ru" );
     //Veritas is outside in playground currently.
     //aboutData.addCredit( ki18n("Manuel Breugelmanns"), ki18n( "Veritas, QTest integraton"), "mbr.nxi@gmail.com" );
@@ -95,7 +95,7 @@ CorePrivate::CorePrivate(Core *core):
 {
 }
 
-bool CorePrivate::initialize(Core::Setup mode, const QString& session )
+bool CorePrivate::initialize(Core::Setup mode, QString session )
 {
     m_mode=mode;
     if( !sessionController )
@@ -123,14 +123,14 @@ bool CorePrivate::initialize(Core::Setup mode, const QString& session )
 
         {
             // check features of kate and report to user if it does not fit
-            KTextEditor::Document* doc = partController->createTextPart(QString());
+            KTextEditor::Document* doc = partController->createTextPart();
 
-            if ( !qobject_cast< KTextEditor::SmartInterface* >(doc) ) {
+            if ( !qobject_cast< KTextEditor::MovingInterface* >(doc) ) {
                 KMessageBox::error(QApplication::activeWindow(),
-                                   i18n("The installed Kate version does not support the SmartInterface which is crucial for"
-                                        "KDevelop up to and including version 4.1.\n\n"
-                                        "To use KDevelop with KDE SC 4.6, where the SmartInterface is replaced by the MovingInterface, "
-                                        "you need KDevelop 4.2 or higher."));
+                                   i18n("The installed Kate version does not support the MovingInterface which is crucial for "
+                                        "KDevelop starting from version 4.2.\n\n"
+                                        "To use KDevelop with KDE SC prior to 4.6, where the SmartInterface is used instead "
+                                        "of the MovingInterface, you need KDevelop 4.1 or lower."));
                 delete doc;
                 return false;
             }
@@ -144,16 +144,18 @@ bool CorePrivate::initialize(Core::Setup mode, const QString& session )
         projectController = new ProjectController(m_core);
     }
 
-    if( !languageController )
-    {
-        languageController = new LanguageController(m_core);
-    }
-
     if( !documentController )
     {
         documentController = new DocumentController(m_core);
     }
 
+    if( !languageController )
+    {
+        // Must be initialized after documentController, because the background parser depends
+        // on the document controller.
+        languageController = new LanguageController(m_core);
+    }
+
     if( !runController )
     {
         runController = new RunController(m_core);
@@ -185,12 +187,20 @@ bool CorePrivate::initialize(Core::Setup mode, const QString& session )
     }
 
     kDebug() << "initializing ui controller";
+    
+    if( !session.isEmpty() && !SessionController::tryLockSession(session) && !(mode & Core::NoUi) )
+    {
+        QString errmsg = i18n("The session %1 is already active in another running instance. Choose another session or close the running instance.", session );
+        session = SessionController::showSessionChooserDialog(errmsg);
+        if(session.isEmpty())
+            return false;
+    }
+    
     sessionController->initialize( session );
 
     if(!sessionController->lockSession())
     {
-        QString errmsg = i18n("This session (%1) is already active in another running instance",
-                              sessionController->activeSession() ? sessionController->activeSession()->description() : "null" );
+        QString errmsg = i18n("Failed to lock the session %1, probably it is already active in another running instance", session );
         if( mode & Core::NoUi ) {
             QTextStream qerr(stderr);
             qerr << endl << errmsg << endl;
