@@ -44,6 +44,7 @@
 #include <interfaces/ilauncher.h>
 #include <interfaces/ilaunchmode.h>
 #include <QLayout>
+#include <QMenu>
 
 namespace KDevelop
 {
@@ -60,8 +61,10 @@ LaunchConfigurationDialog::LaunchConfigurationDialog(QWidget* parent): KDialog(p
     
     addConfig->setIcon( KIcon("list-add") );
     addConfig->setEnabled( false );
+    addConfig->setToolTip(i18n("Add a new launch configuration."));
     deleteConfig->setIcon( KIcon("list-remove") );
     deleteConfig->setEnabled( false );
+    deleteConfig->setToolTip(i18n("Delete selected launch configuration."));
     
     model = new LaunchConfigurationsModel( tree );
     tree->setModel( model );
@@ -127,6 +130,18 @@ LaunchConfigurationDialog::LaunchConfigurationDialog(QWidget* parent): KDialog(p
     }
     tree->setColumnWidth( 0, width );
 
+    QMenu* m = new QMenu(this);
+    foreach(LaunchConfigurationType* type, Core::self()->runController()->launchConfigurationTypes())
+    {
+        QMenu* suggestionsMenu = type->launcherSuggestions();
+        
+        if(suggestionsMenu) {
+            m->addMenu(suggestionsMenu);
+            connect(type, SIGNAL(signalAddLaunchConfiguration(KDevelop::ILaunchConfiguration*)), SLOT(addConfiguration(KDevelop::ILaunchConfiguration*)));
+        }
+    }
+    addConfig->setMenu(m);
+
     connect( this, SIGNAL(okClicked()), SLOT(saveConfig()) );
     connect( this, SIGNAL(applyClicked()), SLOT(saveConfig()) );
 
@@ -304,6 +319,23 @@ void LaunchConfigurationDialog::createConfiguration()
     }
 }
 
+void LaunchConfigurationDialog::addConfiguration(ILaunchConfiguration* _launch)
+{
+    LaunchConfiguration* launch = dynamic_cast<LaunchConfiguration*>(_launch);
+    Q_ASSERT(launch);
+    int row = model->findItemForProject(launch->project())->row;
+    QModelIndex idx  = model->index(row, 0);
+    
+    qDebug() << "pepepe" << idx.isValid() << launch->project()->name();
+    model->addConfiguration(launch, idx);
+    
+    QModelIndex newindex = model->index( model->rowCount( idx ) - 1, 0, idx );
+    tree->selectionModel()->select( newindex, QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows );
+    tree->selectionModel()->setCurrentIndex( newindex, QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows );
+    tree->edit( newindex );
+    tree->resizeColumnToContents( 0 );
+}
+
 LaunchConfigurationsModel::LaunchConfigurationsModel(QObject* parent): QAbstractItemModel(parent)
 {
     GenericPageItem* global = new GenericPageItem;
@@ -682,24 +714,33 @@ void LaunchConfigurationsModel::deleteConfiguration( const QModelIndex& index )
 
 void LaunchConfigurationsModel::createConfiguration(const QModelIndex& parent )
 {
-    TreeItem* t = static_cast<TreeItem*>( parent.internalPointer() );
-    ProjectItem* ti = dynamic_cast<ProjectItem*>( t );
-    if( parent.isValid() && t && !Core::self()->runController()->launchConfigurationTypes().isEmpty() )
+    if(!Core::self()->runController()->launchConfigurationTypes().isEmpty())
     {
-        if( !ti && t->parent )
-        {
-            kWarning() << "Expected project or global item, but didn't find either";
-            return;
-        }
-        beginInsertRows( parent, rowCount( parent ), rowCount( parent ) );
+        TreeItem* t = static_cast<TreeItem*>( parent.internalPointer() );
+        ProjectItem* ti = dynamic_cast<ProjectItem*>( t );
         
         LaunchConfigurationType* type = Core::self()->runController()->launchConfigurationTypes().at(0);
         QPair<QString,QString> launcher = qMakePair( type->launchers().at( 0 )->supportedModes().at(0), type->launchers().at( 0 )->id() );
         IProject* p = ( ti ? ti->project : 0 );
         ILaunchConfiguration* l = Core::self()->runController()->createLaunchConfiguration( type, launcher, p );
+        
+        addConfiguration(l, parent);
+    }
+}
+
+void LaunchConfigurationsModel::addConfiguration(ILaunchConfiguration* l, const QModelIndex& parent)
+{
+    if( parent.isValid() )
+    {
+        beginInsertRows( parent, rowCount( parent ), rowCount( parent ) );
         addItemForLaunchConfig( dynamic_cast<LaunchConfiguration*>( l ) );
         endInsertRows();
     }
+    else
+    {
+        delete l;
+        Q_ASSERT(false && "could not add the configuration");
+    }
 }
 
 LaunchConfigPagesContainer::LaunchConfigPagesContainer( const QList<LaunchConfigurationPageFactory*>& factories, QWidget* parent ) 
