@@ -33,6 +33,7 @@
 #include "../vcsdiff.h"
 
 #include "ui_vcsdiffwidget.h"
+#include "vcsdiffpatchsources.h"
 
 namespace KDevelop
 {
@@ -42,12 +43,28 @@ class VcsDiffWidgetPrivate
 public:
     Ui::VcsDiffWidget* m_ui;
     VcsJob* m_job;
+    VcsDiffWidget* q;
+    
+    VcsDiffWidgetPrivate(VcsDiffWidget* _q) : q(_q) {
+    }
+    
     void diffReady( KDevelop::VcsJob* job )
     {
         if( job != m_job )
             return;
         KDevelop::VcsDiff diff = qVariantValue<KDevelop::VcsDiff>( m_job->fetchResults() );
 
+        // Try using the patch-review plugin if possible
+        VCSDiffPatchSource* patch = new VCSDiffPatchSource(diff);
+        
+        if(showVcsDiff(patch))
+        {
+            q->deleteLater();
+            return;
+        }else{
+            delete patch;
+        }
+        
         kDebug() << "diff:" << diff.leftTexts().count();
         foreach( const KDevelop::VcsLocation &l, diff.leftTexts().keys() )
         {
@@ -64,7 +81,7 @@ public:
 };
 
 VcsDiffWidget::VcsDiffWidget( KDevelop::VcsJob* job, QWidget* parent )
-    : QWidget( parent ), d(new VcsDiffWidgetPrivate)
+    : QWidget( parent ), d(new VcsDiffWidgetPrivate(this))
 {
     d->m_job = job;
     d->m_ui = new Ui::VcsDiffWidget();
